# Welcome to Logbook

<img src="https://raw.githubusercontent.com/getlogbook/logbook/master/docs/_static/logbook-logo.png" width="300">

[![Latest Version][version-img]][pypi]
![Supported Python Versions][pyver-img]
[![GitHub Actions][gha-img]][gha]
[![PyPI Downloads][downloads-img]][pypi]

Logbook is a nice logging replacement.

It should be easy to setup, use and configure and support web applications :)

For more information: https://logbook.readthedocs.org

[version-img]: https://img.shields.io/pypi/v/logbook.svg
[pypi]: https://pypi.org/pypi/Logbook
[gha-img]: https://img.shields.io/github/actions/workflow/status/getlogbook/logbook/main.yml
[gha]: https://github.com/getlogbook/logbook/actions
[downloads-img]: https://img.shields.io/pypi/dm/logbook
[pyver-img]: https://img.shields.io/pypi/pyversions/logbook
